.. _Lucas-Vocos:

Lucas Vocos
:::::::::::::::::::::::::::::::::::::

.. role:: raw-html(raw)
   :format: html

:raw-html:`<font color="CadetBlue"><em>"People have this perception of logic based, math based thinking [as] not very creative, very by the book. People have the perception of creativity and design in another way. I am in a unique place where I can do both. I can help build something beautiful but I can also use logic, use math, use methodologies that achieve that goal."</em></font>`

.. image:: ../../../_static/Interviewees/L_Vocos.jpg
    :width: 350
    :align: right
    :alt: Picture of Lucas

**How did he get into computing?**

*"My parents are from South America. At the time, it was pretty common for people in the Latino community to work for multi-level marketing companies. My dad worked for a number of years for one of these companies but eventually, wanted to work for himself. My first ever use of it was actually building my dad a static site for his company, really just a digital business card."*

**How did he study computing?**

*"Part of the reason why I didn't go to a college was fear of debt. I come from a very low-income, working class Latino family. My dad is an Uber driver and my mom was a domestic worker. We didn't have the resources."*

Lucas couldn't afford college. After high school, he was reintroduced to computing through a retail job at Apple. Eventually, that job led to him building a network and wanting to learn more. He first taught himself using online resources, and he used the skills he learned to enter the industry. Once he had more funds, he also attended a bootcamp to reinforce what he knew.

**What is he working on?**

*"The aim of the project is to help the city of Detroit tackle its digital divide. Quite a bit of the population doesn't have access to broadband internet. Even the parts of Detroit that do have access don't have great access. The idea is to get people connected, get people devices, and get people skills."*

**What does he work as?**

Lucas works as a freelance web developer. In other words, companies contract him to help build websites but he's not tied down to any specific business.

**What advice does he have?**

*"I'm a college dropout. I don't have a formal education, and even then, what I studied in college was definitely not in the STEM world. It wasn't science or technology or anything like that. But I've been working at learning and adapting and learning and so I would say, if you like the thrill of a puzzle, if you can think critically, if you can think methodically, this is an industry that can change your life and that of your family."*


.. youtube:: C_NIICnTb_I
    :divid: Lucas_Vocos
    :height: 315
    :width: 560